@@ -34,7 +34,7 @@ class JobStatus(Enum):
 
 class RepeatedFunction:
     def __init__(self, interval, function, run_initially=False, *args, **kwargs):
-        self._timer = None
+        self._timer: Optional[threading.Timer] = None
         self.interval = interval
         self.function = function
         self.args = args
@@ -58,7 +58,8 @@ class RepeatedFunction:
             self.is_running = True
 
     def stop(self):
-        self._timer.cancel()
+        if self._timer is not None:
+            self._timer.cancel()
         self.is_running = False
 
 
