@@ -3,7 +3,7 @@ import threading
 from datetime import datetime
 from queue import Empty, Queue
 from time import time
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 from scipy.interpolate import interp1d
 
@@ -120,7 +120,7 @@ class DynamicSource:
         # Keep the last/presumably max ix read on record - if in continuous mode this needs to be  added to the requery
         # as an offset.
         self.max_ix_read = 0
-        self.last_get = None
+        self.last_get: Optional[float] = None
         self.status = SourceStatus.STREAM_STARTING
 
         def _next():
@@ -190,9 +190,9 @@ class DynamicSource:
         if self.status not in (SourceStatus.OK, SourceStatus.STREAM_STARTING):
             return self.status
 
+        if self.last_get is None:
+            self.last_get = time()
         try:
-            if self.last_get is None:
-                self.last_get = time()
             row_ = self.row_queue.get(block=True, timeout=1)
             self.last_get = time()
         except Empty:
