@@ -280,10 +280,10 @@ class NumerousClient:
         if not no_log:
             self._init_logger(log_level)
 
-        self.last_progress: float = -999999
+        self.last_progress: float = float('-inf')
         self.progress_debounce = 10
 
-        self.last_state_set = -999999
+        self.last_state_set: float = float('-inf')
         self.state_debounce = 60
 
         clear_data = clear_data if clear_data is not None else config.NUMEROUS_CLEAR_DATA
@@ -361,13 +361,13 @@ class NumerousClient:
         return self._access_token
 
     def _init_logger(self, log_level):
-        log_queue = Queue(-1)
+        log_queue: Queue = Queue(-1)
         numerous_logger = logging.handlers.QueueHandler(queue=log_queue)
         logger = logging.getLogger()
         logger.setLevel(log_level)
         logger.addHandler(numerous_logger)
         self.log_handler = NumerousLogHandler(self)
-        self.log_listener = logging.handlers.QueueListener(log_queue, self.log_handler)
+        self.log_listener = logging.handlers.QueueListener(log_queue, self.log_handler)  # type: ignore[arg-type]
         self.log_listener.start()
         self.logger = logger
 
@@ -474,19 +474,6 @@ class NumerousClient:
 
         return json.loads(model.model), model.files
 
-    def set_scenario_job_image(self, name, path, project=None, scenario=None, job=None):
-        if scenario is None:
-            scenario = self._scenario
-        if project is None:
-            project = self._project
-        if job is None:
-            job = self._job_id
-
-        self._base_client.SetScenarioJobImage(spm_pb2.ScenarioJobImage(
-            project_id=project, scenario_id=scenario, job_id=job,
-            name=name, path=path
-        ))
-
     @retry
     def set_scenario_progress(self, message, status: ScenarioStatus, progress=None, clean=False, scenario=None,
                               force=False, project=None, job=None):
@@ -984,7 +971,7 @@ class NumerousClient:
         for i in range(rest_start, length, size):
             yield data[i:i + size]
 
-    def _rows_to_blocks(self, rows):
+    def _rows_to_blocks(self, rows) -> list[spm_pb2.DataBlock]:
         if len(rows) == 0:
             return []
 
@@ -992,7 +979,7 @@ class NumerousClient:
         estimated_size = sum(len(json.dumps(value)) for value in data.values())
         maximum_block_size = 3.5e6  # allow some overhead
         estimated_chunks = int(math.ceil(estimated_size / maximum_block_size))
-        blocks = [list() for _ in range(estimated_chunks)]
+        blocks: list[spm_pb2.DataBlock] = [list() for _ in range(estimated_chunks)]
 
         # split data into chunks of equal size (except last chunk)
         for tag, values in data.items():
@@ -1064,14 +1051,6 @@ class NumerousClient:
         self._base_client.CloseData(spm_pb2.DataCompleted(scenario=scenario, execution=execution, eta=-1,
                                                           finalized=not self._hibernating))
 
-    def read_configuration(self, name):
-        return self._base_client.ReadConfiguration(spm_pb2.ConfigurationRequest(name=name))
-
-    def store_configuration(self, name, description, datetime_, user, configuration, comment, tags):
-        return self._base_client.StoreConfiguration(
-            spm_pb2.Configuration(name=name, description=description, datetime=datetime_, user=user,
-                                  configuration=configuration, comment=comment, tags=tags))
-
     @contextmanager
     def open_writer(self, aliases: Optional[dict] = None, clear: bool = False,
                     buffer_size: int = 24 * 7) -> Generator[NumerousBufferedWriter, None, None]:
